## **MARINE** : **M**ulti-task lea**R**n**I**ng-based Japa**N**ese accent **E**stimation

## Get started

### Install

```shell
$ pip install marine
```

### For develop

```shell
$ pip install -e ".[dev]"
```
